summaryrefslogtreecommitdiff
path: root/gcc/c-family/c-opts.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/c-family/c-opts.c')
-rw-r--r--gcc/c-family/c-opts.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/gcc/c-family/c-opts.c b/gcc/c-family/c-opts.c
index 9e7f0a361ca..cdbcd6cf874 100644
--- a/gcc/c-family/c-opts.c
+++ b/gcc/c-family/c-opts.c
@@ -110,7 +110,7 @@ static void handle_OPT_d (const char *);
static void set_std_cxx98 (int);
static void set_std_cxx11 (int);
static void set_std_cxx14 (int);
-static void set_std_cxx1z (int);
+static void set_std_cxx17 (int);
static void set_std_c89 (int, int);
static void set_std_c99 (int);
static void set_std_c11 (int);
@@ -631,10 +631,10 @@ c_common_handle_option (size_t scode, const char *arg, int value,
set_std_cxx14 (code == OPT_std_c__14 /* ISO */);
break;
- case OPT_std_c__1z:
- case OPT_std_gnu__1z:
+ case OPT_std_c__17:
+ case OPT_std_gnu__17:
if (!preprocessing_asm_p)
- set_std_cxx1z (code == OPT_std_c__1z /* ISO */);
+ set_std_cxx17 (code == OPT_std_c__17 /* ISO */);
break;
case OPT_std_c90:
@@ -886,7 +886,7 @@ c_common_post_options (const char **pfilename)
/* -Wregister is enabled by default in C++17. */
if (!global_options_set.x_warn_register)
- warn_register = cxx_dialect >= cxx1z;
+ warn_register = cxx_dialect >= cxx17;
/* Declone C++ 'structors if -Os. */
if (flag_declone_ctor_dtor == -1)
@@ -923,9 +923,9 @@ c_common_post_options (const char **pfilename)
if (!global_options_set.x_flag_new_inheriting_ctors)
flag_new_inheriting_ctors = abi_version_at_least (11);
/* For GCC 7, only enable DR150 resolution by default if -std=c++1z. */
if (!global_options_set.x_flag_new_ttp)
- flag_new_ttp = (cxx_dialect >= cxx1z);
+ flag_new_ttp = (cxx_dialect >= cxx17);
if (cxx_dialect >= cxx11)
{
@@ -938,7 +938,7 @@ c_common_post_options (const char **pfilename)
warn_narrowing = 1;
/* Unless -f{,no-}ext-numeric-literals has been used explicitly,
- for -std=c++{11,14,1z} default to -fno-ext-numeric-literals. */
+ for -std=c++{11,14,17} default to -fno-ext-numeric-literals. */
if (flag_iso && !global_options_set.x_flag_ext_numeric_literals)
cpp_opts->ext_numeric_literals = 0;
}
@@ -949,7 +949,7 @@ c_common_post_options (const char **pfilename)
for earlier C++ as well, so chaining works as expected. */
if (c_dialect_cxx ()
&& flag_strong_eval_order == -1)
- flag_strong_eval_order = (cxx_dialect >= cxx1z ? 2 : 1);
+ flag_strong_eval_order = (cxx_dialect >= cxx17 ? 2 : 1);
/* Global sized deallocation is new in C++14. */
if (flag_sized_deallocation == -1)
@@ -1581,7 +1581,7 @@ set_std_cxx11 (int iso)
lang_hooks.name = "GNU C++11";
}
-/* Set the C++ 2014 draft standard (without GNU extensions if ISO). */
+/* Set the C++ 2014 standard (without GNU extensions if ISO). */
static void
set_std_cxx14 (int iso)
{
@@ -1596,11 +1596,11 @@ set_std_cxx14 (int iso)
lang_hooks.name = "GNU C++14";
}
-/* Set the C++ 201z draft standard (without GNU extensions if ISO). */
+/* Set the C++ 2017 standard (without GNU extensions if ISO). */
static void
-set_std_cxx1z (int iso)
+set_std_cxx17 (int iso)
{
- cpp_set_lang (parse_in, iso ? CLK_CXX1Z: CLK_GNUCXX1Z);
+ cpp_set_lang (parse_in, iso ? CLK_CXX17: CLK_GNUCXX17);
flag_no_gnu_keywords = iso;
flag_no_nonansi_builtin = iso;
flag_iso = iso;
@@ -1608,8 +1608,8 @@ set_std_cxx1z (int iso)
flag_isoc94 = 1;
flag_isoc99 = 1;
flag_isoc11 = 1;
- cxx_dialect = cxx1z;
- lang_hooks.name = "GNU C++14"; /* Pretend C++14 till standarization. */
+ cxx_dialect = cxx17;
+ lang_hooks.name = "GNU C++17";
}
/* Args to -d specify what to dump. Silently ignore
@@ -923,9 +923,9 @@ c_common_post_options (const char **pfilename)
if (!global_options_set.x_flag_new_inheriting_ctors)
flag_new_inheriting_ctors = abi_version_at_least (11);
- /* For GCC 7, only enable DR150 resolution by default if -std=c++1z. */
+ /* For GCC 7, only enable DR150 resolution by default if -std=c++17. */
if (!global_options_set.x_flag_new_ttp)